@@ -73,12 +73,7 @@ class OpenstackExporter(Exporter):
 
                 network_info = json.loads(output.communicate()[0])
 
-                # Subnet information is presented as a plaintext, possibly with multiple lines,
-                # one subnet per line. No JSON structure...
-                for subnet_raw_info in network_info['subnet_ip_availability'].split('\n'):
-                    subnet_raw_info = subnet_raw_info.strip()
-
-                    subnet_info = dict(re.findall(r"(\S+)='(.*?|\S+)'", subnet_raw_info))
+                for subnet_info in network_info['subnet_ip_availability']:
 
                     if subnet_info['ip_version'] != '4':
                         continue
